==> zio-aws-kafka_3-5.17.103.1-sources.jar: zio/aws/kafka/model/ListTagsForResourceRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class ListTagsForResourceRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.ListTagsForResourceRequest
      .builder()
      .resourceArn(__string.unwrap(resourceArn): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.kafka.model.ListTagsForResourceRequest.wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.ListTagsForResourceRequest =
      zio.aws.kafka.model.ListTagsForResourceRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.ListTagsForResourceRequest
  ) extends zio.aws.kafka.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceArn: __string =
      zio.aws.kafka.model.primitives.__string(impl.resourceArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.ListTagsForResourceRequest
  ): zio.aws.kafka.model.ListTagsForResourceRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_3-5.17.146.1-sources.jar: zio/aws/kafka/model/ListTagsForResourceRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class ListTagsForResourceRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.ListTagsForResourceRequest
      .builder()
      .resourceArn(resourceArn: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.kafka.model.ListTagsForResourceRequest.wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.ListTagsForResourceRequest =
      zio.aws.kafka.model.ListTagsForResourceRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.ListTagsForResourceRequest
  ) extends zio.aws.kafka.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceArn: __string = impl.resourceArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.ListTagsForResourceRequest
  ): zio.aws.kafka.model.ListTagsForResourceRequest.ReadOnly = new Wrapper(impl)
}
